@@ -7,7 +7,11 @@ from setuptools_scm.utils import do
 
 @pytest.fixture
 def wd(wd):
-    wd("git init")
+    try:
+        wd("git init")
+    except FileNotFoundError:
+        pytest.skip("git executable not found")
+
     wd("git config user.email test@example.com")
     wd('git config user.name "a test"')
     wd.add_command = "git add ."
@@ -16,6 +20,7 @@ def wd(wd):
 
 
 def test_pyproject_support(tmpdir, monkeypatch):
+    pytest.importorskip("toml")
     monkeypatch.delenv("SETUPTOOLS_SCM_DEBUG")
     pkg = tmpdir.ensure("package", dir=42)
     pkg.join("pyproject.toml").write(
@@ -28,7 +33,6 @@ fallback_version = "12.34"
     assert res == "12.34"
 
 
-@pytest.mark.xfail(reason="#174")
 def test_pyproject_support_with_git(tmpdir, monkeypatch, wd):
     monkeypatch.delenv("SETUPTOOLS_SCM_DEBUG")
     pkg = tmpdir.join("wd")
